@@ -29,11 +29,15 @@ import java.net.PasswordAuthentication;
 import java.net.ServerSocket;
 import java.net.Socket;
 import java.net.SocketException;
+import java.net.SocketTimeoutException;
 import java.net.URL;
 import java.net.URLConnection;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.Enumeration;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
@@ -43,18 +47,20 @@ import org.apache.commons.logging.LogFactory;
 import org.apache.log4j.PropertyConfigurator;
 import org.apache.log4j.helpers.LogLog;
 
+import com.clustercontrol.agent.filecheck.FileCheckManager;
+import com.clustercontrol.agent.job.RunHistoryUtil;
 import com.clustercontrol.agent.log.LogfileMonitorManager;
 import com.clustercontrol.agent.util.AgentProperties;
 import com.clustercontrol.agent.util.PropertiesFileUtil;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.repository.bean.AgentCommandConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.agent.AgentInfo;
 import com.clustercontrol.ws.agent.HinemosUnknown_Exception;
 import com.clustercontrol.ws.agent.InvalidRole_Exception;
 import com.clustercontrol.ws.agent.InvalidUserPass_Exception;
-import com.clustercontrol.ws.agent.OutputBasicInfo;
 
 /**
  * エージェントメインクラス<BR>
@@ -82,14 +88,13 @@ public class Agent {
 
 	public static final Integer DEFAULT_CONNECT_TIMEOUT = 10;
 	public static final Integer DEFAULT_REQUEST_TIMEOUT = 60;
-	
+
 	public static final String DEFAULT_PROXY_HOST = "";
 	public static final int DEFAULT_PROXY_PORT = 8080;
 	public static final String DEFAULT_PROXY_USER = "";
 	public static final String DEFAULT_PROXY_PASSWORD = "";
 	
 	private static final String REPLACE_VALUE_MANAGER_IP = "${ManagerIP}";
-	
 
 	/*
 	 * AgentHome
@@ -114,91 +119,94 @@ public class Agent {
 			System.exit(1);
 		}
 
-		try {
-			// Systemプロパティ
-			m_log.info("starting Hinemos Agent...");
-			m_log.info("java.vm.version = " + System.getProperty("java.vm.version"));
-			m_log.info("java.vm.vendor = " + System.getProperty("java.vm.vendor"));
-			m_log.info("java.home = " + System.getProperty("java.home"));
-			m_log.info("os.name = " + System.getProperty("os.name"));
-			m_log.info("os.arch = " + System.getProperty("os.arch"));
-			m_log.info("os.version = " + System.getProperty("os.version"));
-			m_log.info("user.name = " + System.getProperty("user.name"));
-			m_log.info("user.dir = " + System.getProperty("user.dir"));
-			m_log.info("user.country = " + System.getProperty("user.country"));
-			m_log.info("user.language = " + System.getProperty("user.language"));
-			m_log.info("file.encoding = " + System.getProperty("file.encoding"));
+		// Systemプロパティ
+		m_log.info("starting Hinemos Agent...");
+		m_log.info("java.vm.version = " + System.getProperty("java.vm.version"));
+		m_log.info("java.vm.vendor = " + System.getProperty("java.vm.vendor"));
+		m_log.info("java.home = " + System.getProperty("java.home"));
+		m_log.info("os.name = " + System.getProperty("os.name"));
+		m_log.info("os.arch = " + System.getProperty("os.arch"));
+		m_log.info("os.version = " + System.getProperty("os.version"));
+		m_log.info("user.name = " + System.getProperty("user.name"));
+		m_log.info("user.dir = " + System.getProperty("user.dir"));
+		m_log.info("user.country = " + System.getProperty("user.country"));
+		m_log.info("user.language = " + System.getProperty("user.language"));
+		m_log.info("file.encoding = " + System.getProperty("file.encoding"));
 
-			// TODO プロパティファイルのフォルダの親がagentHome。
-			// あまり良くない実装なので、修正予定。
-			File file = new File(args[0]);
-			agentHome = file.getParentFile().getParent() + "/";
-			m_log.info("agentHome=" + agentHome);
+		// TODO プロパティファイルのフォルダの親がagentHome。
+		// あまり良くない実装なので、修正予定。
+		File file = new File(args[0]);
+		agentHome = file.getParentFile().getParent() + "/";
+		m_log.info("agentHome=" + agentHome);
 
-			// 起動時刻
-			long startDate = System.currentTimeMillis();
-			m_log.info("start date = " + new Date(startDate) + "(" + startDate + ")");
-			agentInfo.setStartupTime(startDate);
+		// 起動時刻
+		long startDate = System.currentTimeMillis();
+		m_log.info("start date = " + new Date(startDate) + "(" + startDate + ")");
+		agentInfo.setStartupTime(startDate);
 
-			// Agent設定の初期化
-			m_log.info("Agent.properties = " + args[0]);
-			// ログ再読み込みの機構初期化
-			m_log.info("log4j.properties = " + args[1]);
+		// Agent設定の初期化
+		m_log.info("Agent.properties = " + args[0]);
+		// ログ再読み込みの機構初期化
+		m_log.info("log4j.properties = " + args[1]);
 
-			// Agentインスタンス作成
-			Agent agent = new Agent(args[0], args[1]);
+		// Agentインスタンス作成
+		Agent agent = new Agent(args[0], args[1]);
 
-			// エージェント処理開始
-			agent.exec();
+		//エージェント処理開始
+		agent.exec();
 
-			m_log.info("Hinemos Agent started");
+		m_log.info("Hinemos Agent started");
 
-			// 終了待ち
-			agent.waitAwakeAgent();
-		} catch (Throwable e){
-			m_log.error("Agent.java: Runtime Exception Occurred. " + e.getClass().getName()+ ", " + e.getMessage(), e);
-		}
+
+		//終了待ち
+		agent.waitAwakeAgent();
 	}
 
 	/**
 	 * マネージャのawakeAgentを待つメソッド。
-	 * UDP 24005にパケットが送られてきたら、ラッチを開放する(releaseLatch)。
+	 * Agent.propertiesに指定されたUDPポート（デフォルト：24005）にパケットが送られてきたら、ラッチを開放する(releaseLatch)。
 	 * ラッチが開放されたReceiveTopicは、マネージャからTopicを取りに行く。
 	 */
 	public void waitAwakeAgent () {
 		final int BUFSIZE = 1;
 		int port = 24005;
+
+		// awakeAgentを待つポート番号を Agent.propertiesから取得する
+		String portStr = AgentProperties.getProperty("awake.port",
+				Integer.toString(port));
+		port = Integer.parseInt(portStr);
+
 		byte[] buf = new byte[BUFSIZE];
 		InetAddress cAddr;		// マネージャのIPアドレス
 		int cPort;				// マネージャのポート
 		DatagramSocket sock = null;
-		
-		try {
-			port = Integer.parseInt(AgentProperties.getProperty("awake.port", "24005"));
-		} catch (Exception e) {
-			m_log.warn("awake.port is invalid. " + e.getMessage());
-		}
-		m_log.info("awake.port(udp)=" + port);
-		
-		try {
-			sock = new DatagramSocket(port);
-		} catch (Exception e) {
-			m_log.warn("waitAwakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-			m_log.warn("waitAwakeAgent : sock is null");
-		}
+		boolean flag = true;
 		while (true) {
+			/*
+			 * UDPパケットを受信したらflagがtrueになる。
+			 * その後に、flagがfalseになったら、getTopicを実行(releaseLatch)する。
+			 * 
+			 * UDPパケットを大量に受け取ってもgetTopicが大量発行されないように、
+			 * このような実装とする。
+			 */
 			try {
-				Thread.sleep(500);
-				if (sock == null) {
-					continue;
+				if (sock == null || !sock.isBound()) {
+					sock = new DatagramSocket(port);
+					sock.setSoTimeout(1000);
 				}
 				DatagramPacket recvPacket = new DatagramPacket(buf, BUFSIZE);
 				sock.receive(recvPacket);
 				cAddr = recvPacket.getAddress();
 				cPort = recvPacket.getPort();
+				flag = true;
 				m_log.info("waitAwakeAgent (" + cAddr.getHostAddress() +
 						" onPort=" + cPort + ") buf.length=" + buf.toString().length());
-				m_receiveTopic.releaseLatch();
+			} catch (SocketTimeoutException e) {
+				if (flag) {
+					m_log.info("waitAwakeAgent packet end");
+					m_receiveTopic.releaseLatch();
+					flag = false;
+				}
 			} catch (Exception e) {
 				String msg = "waitAwakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage();
 				m_log.warn(msg);
@@ -211,14 +219,21 @@ public class Agent {
 			}
 		}
 	}
-	
+
+
 	/**
-	 * マネージャのsendManagerIpを待つメソッド。
+	 * マネージャのsendManagerDiscoveryInfoを待つメソッド。
 	 * TCP 24005にパケットが送られてきたら、パケット内のメッセージ（IPアドレス）を返す。
-	 * @throws Exception 
+	 * 
+	 * @throws Exception
 	 */
-	private String receiveManagerIp() throws Exception{
-		final int port = 24005;
+	private String receiveManagerDiscoveryInfo() throws Exception {
+		int default_port = 24005;
+		String portStr = AgentProperties.getProperty("discovery.pingport", Integer.toString(default_port));
+		int port = Integer.parseInt(portStr);
+		if (port < 1 || port > 65535) {
+			port = default_port;
+		}
 		ServerSocket servSock = null;
 		Socket clntSock = null;
 
@@ -227,13 +242,14 @@ public class Agent {
 		int recvMsgSize = 0;
 		byte[] receiveBuf = new byte[BUFSIZE];
 		String recvMsg = "";
-		
+
 		try {
 			servSock = new ServerSocket(port);
-			
+
 			// マネージャからの接続を待つ
 			clntSock = servSock.accept();
-			m_log.info("connecting to： " + clntSock.getRemoteSocketAddress().toString());
+			m_log.info("connecting to： "
+					+ clntSock.getRemoteSocketAddress().toString());
 
 			InputStream in = clntSock.getInputStream();
 			OutputStream out = clntSock.getOutputStream();
@@ -242,31 +258,26 @@ public class Agent {
 				out.write(receiveBuf, 0, tmpRecvMsgSize);
 				recvMsgSize = tmpRecvMsgSize;
 			}
-			
+
 			recvMsg = new String(receiveBuf, 0, recvMsgSize);
-			m_log.info("receiveMessage : " + recvMsg);
-			
-			if(!(recvMsg.contains("agentFacilityId=") && recvMsg.contains("managerIp="))){
-				throw new HinemosUnknown("receive message is invalid");
-			}
-			
-			m_log.info("receive message: " + recvMsg);
+			m_log.info("receive message : " + recvMsg);
 		} catch (Exception e) {
-			m_log.warn("receiveManagerIp " + e.getClass().getSimpleName() + ", " + e.getMessage());
+			m_log.warn("receiveManagerIp " + e.getClass().getSimpleName()
+					+ ", " + e.getMessage());
 			throw e;
 		} finally {
-			try{
-				if(clntSock != null){
+			try {
+				if (clntSock != null) {
 					clntSock.close();
 				}
-			} catch(Exception e) {
+			} catch (Exception e) {
 				m_log.warn("receiveManagerIp: " + e);
 			}
-			try{
-				if(servSock != null){
+			try {
+				if (servSock != null) {
 					servSock.close();
 				}
-			} catch(Exception e) {
+			} catch (Exception e) {
 				m_log.warn("receiveManagerIp: " + e);
 			}
 		}
@@ -282,13 +293,13 @@ public class Agent {
 		//-- 初期処理
 		//------------
 
-		//プロパティファイル読み込み初期化
-		AgentProperties.init(propFileName);
-
 		// エージェントのIPアドレス、ホスト名をログに出力。
 		getAgentInfo();
 		m_log.info(getAgentStr());
 
+		//プロパティファイル読み込み初期化
+		AgentProperties.init(propFileName);
+
 		// log4j設定ファイル再読み込み設定
 		if(log4jFileName == null){
 			m_log.error("log4j.properties does not specify!");
@@ -299,17 +310,17 @@ public class Agent {
 
 		int connectTimeout = DEFAULT_CONNECT_TIMEOUT;
 		int requestTimeout = DEFAULT_REQUEST_TIMEOUT;
-		
+
 		// プロキシ設定
 		String proxyHost = DEFAULT_PROXY_HOST;
 		int proxyPort = DEFAULT_PROXY_PORT;
 		String proxyUser = DEFAULT_PROXY_USER;
 		String proxyPassword = DEFAULT_PROXY_PASSWORD;
-		
+
 		try {
 			String strConnect = AgentProperties.getProperty("connect.timeout");
 			if (strConnect != null) {
-				connectTimeout = Integer.parseInt(strConnect);
+				requestTimeout = Integer.parseInt(strConnect);
 			}
 			String strRequest = AgentProperties.getProperty("request.timeout");
 			if (strRequest != null) {
@@ -334,7 +345,7 @@ public class Agent {
 		} catch (Exception e) {
 			m_log.warn(e.getMessage());
 		}
-		
+
 		if(!"".equals(proxyHost)){
 			System.setProperty("http.proxyHost", proxyHost);
 			System.setProperty("http.proxyPort", Integer.toString(proxyPort));
@@ -342,41 +353,73 @@ public class Agent {
 			Authenticator.setDefault(basicAuth);
 			m_log.info("proxy.host=" + System.getProperty("http.proxyHost") + ", proxy.port=" + System.getProperty("http.proxyPort") + ", proxy.user=" + proxyUser);
 		}
-		
-		// マネージャからの接続を待ち、接続先マネージャを指定する
+
+
+		// 設定ファイルの接続先アドレスに ${ManagerIP} の指定があった場合に限りマネージャからの接続を待ち、
+		// マネージャのPINGを受け取って、接続先マネージャのIPアドレスの設定反映や自身のFacilityIDの書き換えを行う
 		String managerAddress = AgentProperties.getProperty("managerAddress");
 		URL url = new URL(managerAddress);
 		boolean replacePropFileSuccess = true;
 		String errMsg = "";
-		if(REPLACE_VALUE_MANAGER_IP.equals((url.getHost()))){
-			try{
-				m_log.info("waiting for manager connection...");
-				String recvMsg = receiveManagerIp();
+		if (REPLACE_VALUE_MANAGER_IP.equals((url.getHost()))) {
+			try {
 				
-				String managerIp = recvMsg.split(",")[0].split("=")[1];
-				String agentFacilityId = recvMsg.split(",")[1].split("=")[1];
-
-				String key = "managerAddress";
-				String value = url.getProtocol() + "://" + managerIp + ":" + url.getPort() + "/HinemosWS/";
-				m_log.info("key : " + key);
-				m_log.info("value : " + value);
-				// Agent.propertiesファイルの接続先マネージャ書き換え
-				PropertiesFileUtil.replacePropertyFile(propFileName, key, managerAddress, value);
-				AgentProperties.setProperty(key, value);
+				// マネージャからのPINGを待ちうけ、正常なPINGが来るまで繰り返し待ち続ける
+				Map<String, String> discoveryInfoMap = new HashMap<String, String>();
+				while (true) {
+					m_log.info("waiting for manager connection...");
+					String recvMsg = receiveManagerDiscoveryInfo();
+					
+					// 受信したメッセージを、key=value,key=value の形式で解析し、Mapにする
+					try {
+						discoveryInfoMap.clear();
+						String[] commaSplittedRecvMsgArray = recvMsg.split(",");
+						for (String keyvalueset : commaSplittedRecvMsgArray) {
+							String key = keyvalueset.split("=")[0];
+							String value = keyvalueset.split("=")[1];
+							discoveryInfoMap.put(key, value);
+						}
+					} catch (Exception e) {
+						m_log.error("can't parse receive message : " + e.toString());
+						continue;
+					}
+					if (discoveryInfoMap.containsKey("agentFacilityId") && discoveryInfoMap.containsKey("managerIp")) {
+						break;
+					} else {
+						m_log.error("receive message is invalid");
+					}
+				}
+				// Agent.propertiesファイルの接続先マネージャの書き換え＋動作中のプロパティの書き換え
+				{
+					String managerIp = discoveryInfoMap.get("managerIp");
+					String key = "managerAddress";
+					String value = url.getProtocol() + "://" + managerIp + ":"
+							+ url.getPort() + "/HinemosWS/";
+					m_log.info("Rewrite property. key : " + key + ", value : " + value);
+					PropertiesFileUtil.replacePropertyFile(propFileName, key, managerAddress, value);
+					AgentProperties.setProperty(key, value);
+				}
 				
-				key = "facilityId";
-				m_log.info("key : " + key);
-				m_log.info("value : " + agentFacilityId);
-				// Agent.propertiesファイルのエージェントファシリティID書き換え
-				PropertiesFileUtil.replacePropertyFile(propFileName, key, "", agentFacilityId);
-				AgentProperties.setProperty(key, agentFacilityId);
+				// Agent.propertiesファイルのエージェントファシリティID書き換え＋動作中のプロパティの書き換え
+				{
+					String key = "facilityId";
+					String value = discoveryInfoMap.get("agentFacilityId");
+					m_log.info("Rewrite property. key : " + key + ", value : " + value);
+					PropertiesFileUtil.replacePropertyFile(propFileName, key, "", value);
+					AgentProperties.setProperty(key, value);
+				}
 				
-				key = "log4j.appender.syslog.SyslogHost";
 				// log4j.propertiesファイルの書き換え（Windows版エージェントのみ）
-				if(REPLACE_VALUE_MANAGER_IP.equals(AgentProperties.getProperty(key))){
-					m_log.info("key : " + key);
-					m_log.info("value : " + managerIp);
-					PropertiesFileUtil.replacePropertyFile(log4jFileName, key, REPLACE_VALUE_MANAGER_IP, managerIp);
+				{
+					String managerIp = discoveryInfoMap.get("managerIp");
+					String key = "log4j.appender.syslog.SyslogHost";
+					PropertiesFileUtil.replacePropertyFile(log4jFileName,
+							"log4j.appender.syslog.SyslogHost",
+							REPLACE_VALUE_MANAGER_IP, managerIp);
+					if (REPLACE_VALUE_MANAGER_IP.equals(AgentProperties.getProperty(key))) {
+						m_log.info("Rewrite property. key : " + key + ", value : " + managerIp);
+						PropertiesFileUtil.replacePropertyFile(log4jFileName, key, REPLACE_VALUE_MANAGER_IP, managerIp);
+					}
 				}
 			} catch (HinemosUnknown e) {
 				// プロパティファイル書き換えに失敗した場合、マネージャに通知する
@@ -388,7 +431,7 @@ public class Agent {
 				throw e;
 			}
 		}
-
+		
 		try {
 			EndpointManager.init(AgentProperties.getProperty("user"),
 					AgentProperties.getProperty("password"),
@@ -399,16 +442,18 @@ public class Agent {
 			m_log.error("current-dir=" + (new File(".")).getAbsoluteFile().getParent());
 			throw e;
 		}
-		
-		if(!replacePropFileSuccess){
+
+		if (!replacePropFileSuccess) {
 			OutputBasicInfo output = new OutputBasicInfo();
 			output.setPluginId("AGT_UPDATE_CONFFILE");
 			output.setPriority(PriorityConstant.TYPE_WARNING);
 			output.setApplication(Messages.getString("agent"));
 			output.setMessageId("001");
-			String[] args = {errMsg};
-			output.setMessage(Messages.getString("message.agent.replace.file.faulure.notify.msg"));
-			output.setMessageOrg(Messages.getString("message.agent.replace.file.faulure.notify.origmsg", args));
+			String[] args = { errMsg };
+			output.setMessage(Messages
+					.getString("message.agent.replace.file.faulure.notify.msg"));
+			output.setMessageOrg(Messages.getString(
+					"message.agent.replace.file.faulure.notify.origmsg", args));
 			output.setGenerationDate(new Date().getTime());
 			output.setMonitorId("SYS");
 			output.setFacilityId(""); // マネージャがセットする。
@@ -448,8 +493,11 @@ public class Agent {
 				m_reconfigLog4jInterval,m_reconfigLog4jInterval,TimeUnit.SECONDS);
 
 		// ログファイル読み込みスレッド開始
-		LogfileMonitorManager manager = new LogfileMonitorManager(m_sendQueue);
-		manager.start();
+		LogfileMonitorManager.start();
+
+		// ファイルチェック(ジョブ)読み込みスレッド開始
+		FileCheckManager fileCheckManager = new FileCheckManager();
+		fileCheckManager.start();
 
 	}
 
@@ -458,7 +506,7 @@ public class Agent {
 	 */
 	public void terminate() {
 		m_log.info("terminate() start");
-		m_receiveTopic.logHistory();
+		RunHistoryUtil.logHistory();
 
 		try {
 			AgentEndPointWrapper.deleteAgent();
@@ -714,15 +762,14 @@ public class Agent {
 }
 
 class BasicAuth extends Authenticator{
-	 private String username;
-	 private String password;
-	 public BasicAuth(String username, String password)
-	 {
-		 this.username = username;
-		 this.password = password;
-	 }
-
-	 protected PasswordAuthentication getPasswordAuthentication() {
-		 return new PasswordAuthentication(username,password.toCharArray());
-	 }
+	private String username;
+	private String password;
+	public BasicAuth(String username, String password){
+		this.username = username;
+		this.password = password;
+	}
+	@Override
+	protected PasswordAuthentication getPasswordAuthentication() {
+		return new PasswordAuthentication(username,password.toCharArray());
+	}
 }
\ No newline at end of file
