@@ -16,9 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.agent;
 
 import java.util.ArrayList;
-import java.util.ConcurrentModificationException;
-import java.util.Date;
-import java.util.Hashtable;
 import java.util.List;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
@@ -27,32 +24,37 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.agent.bean.TopicFlagConstant;
-import com.clustercontrol.agent.custom.CollectorManager;
 import com.clustercontrol.agent.custom.CommandCollector;
-import com.clustercontrol.agent.custom.CommandCollector.CollectorId;
+import com.clustercontrol.agent.filecheck.FileCheckManager;
 import com.clustercontrol.agent.job.CheckSumThread;
 import com.clustercontrol.agent.job.CommandThread;
+import com.clustercontrol.agent.job.DeleteProcessThread;
 import com.clustercontrol.agent.job.FileListThread;
 import com.clustercontrol.agent.job.PublicKeyThread;
 import com.clustercontrol.agent.job.RunHistoryUtil;
 import com.clustercontrol.agent.log.LogfileMonitorManager;
 import com.clustercontrol.agent.update.UpdateModuleUtil;
 import com.clustercontrol.agent.util.AgentProperties;
-import com.clustercontrol.bean.PluginConstant;
+import com.clustercontrol.agent.util.CollectorId;
+import com.clustercontrol.agent.util.CollectorManager;
+import com.clustercontrol.agent.util.CommandMonitoringWSUtil;
+import com.clustercontrol.agent.winevent.WinEventCollector;
+import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.jobmanagement.bean.CommandConstant;
+import com.clustercontrol.jobmanagement.bean.CommandStopTypeConstant;
 import com.clustercontrol.jobmanagement.bean.CommandTypeConstant;
-import com.clustercontrol.jobmanagement.bean.RunStatusConstant;
 import com.clustercontrol.repository.bean.AgentCommandConstant;
-import com.clustercontrol.util.CommandMonitoringWSUtil;
+import com.clustercontrol.ws.agent.HinemosTopicInfo;
 import com.clustercontrol.ws.agent.HinemosUnknown_Exception;
 import com.clustercontrol.ws.agent.InvalidRole_Exception;
 import com.clustercontrol.ws.agent.InvalidUserPass_Exception;
 import com.clustercontrol.ws.agent.CustomInvalid_Exception;
+import com.clustercontrol.ws.agent.JobMasterNotFound_Exception;
 import com.clustercontrol.ws.agent.MonitorNotFound_Exception;
 import com.clustercontrol.ws.agent.SettingUpdateInfo;
 import com.clustercontrol.ws.agent.TopicInfo;
+import com.clustercontrol.ws.jobmanagement.JobFileCheck;
 import com.clustercontrol.ws.jobmanagement.RunInstructionInfo;
-import com.clustercontrol.ws.jobmanagement.RunResultInfo;
 import com.clustercontrol.ws.monitor.CommandExecuteDTO;
 import com.clustercontrol.ws.monitor.MonitorInfo;
 
@@ -70,12 +72,11 @@ public class ReceiveTopic extends Thread {
 	//protected ArrayList<String> m_facilityIdList;
 	private SendQueue m_sendQueue;
 
-	private static Hashtable<String, Date> m_runHistory;
-
 	private int m_topicInterval = 30000;
-	private int m_topicFastInterval = 1000;
-	private int m_topicFastCount = 10;
 	private long m_runhistoryClearDelay = -1;
+	
+	// Topicを4.1モードで動作させる。
+	private boolean newTopicMode = true; 
 
 	// マネージャと接続できている場合、フラグはtrueになる。
 	private long disconnectCounter = 1;
@@ -83,7 +84,7 @@ public class ReceiveTopic extends Thread {
 	private static boolean m_reloadFlg = false;
 
 	// 最後に受信した設定情報更新日時
-	private static SettingUpdateInfo commandMonitorLastUpdateInfo = null;
+	private static SettingUpdateInfo settingLastUpdateInfo = null;
 
 	/**
 	 * コンストラクタ
@@ -95,7 +96,6 @@ public class ReceiveTopic extends Thread {
 	public ReceiveTopic(SendQueue sendQueue) {
 		super();
 		m_sendQueue = sendQueue;
-		m_runHistory = new Hashtable<String, Date>();
 
 		m_log.info("create ReceiveTopic ");
 
@@ -113,29 +113,6 @@ public class ReceiveTopic extends Thread {
 			}
 		}
 
-		str = "topic.fast.interval";
-		interval = AgentProperties.getProperty(str);
-		if (interval != null) {
-			try {
-				// プロパティファイルにはmsecで記述
-				m_topicFastInterval = Integer.parseInt(interval);
-				m_log.info(str + " = " + m_topicFastInterval + " msec");
-			} catch (NumberFormatException e) {
-				m_log.error(str,e);
-			}
-		}
-
-		str = "topic.fast.count";
-		interval = AgentProperties.getProperty(str);
-		if (interval != null) {
-			try {
-				m_topicFastCount = Integer.parseInt(interval);
-				m_log.info(str + " = " + m_topicFastCount);
-			} catch (NumberFormatException e) {
-				m_log.error(str,e);
-			}
-		}
-
 		// ジョブ実行履歴の削除実行時間を取得
 		String delay = AgentProperties.getProperty("runhistory.clear.delay");
 		if (delay != null) {
@@ -148,8 +125,15 @@ public class ReceiveTopic extends Thread {
 			}
 		}
 
-		// ログファイル監視のマネージャを生成
-		m_logManager = new LogfileMonitorManager(m_sendQueue);
+		// Topicのモードを4.0モードにするか4.1モードにするか。
+		String mode = AgentProperties.getProperty("topic.mode");
+		if (mode != null && "4.0".equals(mode)) {
+			newTopicMode = false;
+		}
+		m_log.info("newTopicMode=" + newTopicMode);
+		
+		// マネージャとの接続queueを設定
+		LogfileMonitorManager.setSendQueue(m_sendQueue);
 	}
 
 
@@ -173,27 +157,13 @@ public class ReceiveTopic extends Thread {
 
 		m_log.info("run start");
 
-		int fastCount = 1;
 		while (true) {
 			/*
 			 * トピックの有無をマネージャにチェックし終わったら、sleepする。
 			 * 
-			 * 一度、Topicにジョブチェックが含まれている場合は、fastモードになり、sleep時間が短くなる。
-			 * それ以外の場合は、slowモードになり、sleep時間が長くなる。
-			 * (ジョブチェックのTopicの受信直後には、再度Topicが来る。)
 			 */
 			try {
-				int interval;
-				/*
-				 * fastフラグが立っている場合、その後、
-				 * m_topicFastCount回、intervalがm_topicFastIntervalとなる。
-				 */
-				if (fastCount > 0) {
-					interval = m_topicFastInterval;
-					fastCount --;
-				} else {
-					interval = m_topicInterval;
-				}
+				int interval = m_topicInterval;
 				countDownLatch = new CountDownLatch(1);
 				countDownLatch.await(interval, TimeUnit.MILLISECONDS);
 			} catch (InterruptedException e) {
@@ -205,11 +175,11 @@ public class ReceiveTopic extends Thread {
 			try {
 				List<RunInstructionInfo> runInstructionList = new ArrayList<RunInstructionInfo>();
 				m_log.info("getTopic " + Agent.getAgentStr() + " start");
+				HinemosTopicInfo hinemosTopicInfo = null;
 				List<TopicInfo> topicInfoList = null;
 				SettingUpdateInfo updateInfo = null;
 				try {
-					topicInfoList = AgentEndPointWrapper.getTopic();
-					updateInfo = AgentEndPointWrapper.getSettingUpdateInfo();
+					hinemosTopicInfo = AgentEndPointWrapper.getHinemosTopic();
 				} catch (Exception e) {
 					/*
 					 * マネージャが停止している、もしくはマネージャと通信ができないと、
@@ -230,67 +200,42 @@ public class ReceiveTopic extends Thread {
 					 * どうしても見たかったらdebugにする。
 					 */
 					String message = "run() getTopic : " + e.getClass().getSimpleName() +
-					", " + e.getMessage();
+							", " + e.getMessage();
 					m_log.warn(message);
 					m_log.debug(message, e);
 					continue; // whileまで戻る。
 				}
-				/*
-				 * マネージャと接続直後の場合、ここで転送ログファイル、カスタム監視情報のリストを受け取り、リロードフラグをオフにする。
-				 */
-				if (disconnectCounter != 0) {
-					reloadLogfileMonitor();
-					reloadCommandMonitoring(updateInfo);
-					setReloadFlg(false);
-				}
-				disconnectCounter = 0;
-				setClearFlg(false);
 
-				if (topicInfoList.size() == 0 && isCommandMonitoringUpdated(updateInfo)) {
-					// コマンド監視のリロードを行う
-					reloadCommandMonitoring(updateInfo);
-				}
-				
-				// 監視リロードフラグが有効の場合、カスタム監視、ログファイル監視のリロードを行う
-				// IPアドレスに変化があった場合
-				if (isReloadMonitor()) {
-					m_log.info("reloading configuration");
-					reloadCommandMonitoring(updateInfo);
-					reloadLogfileMonitor();
+				// マネージャから取得した情報を関連クラスに配置する
+				topicInfoList = hinemosTopicInfo.getTopicInfoList();
+				updateInfo = hinemosTopicInfo.getSettingUpdateInfo();
+
+				/*
+				 * マネージャと接続直後の場合、ここで転送ログファイル、カスタム監視情報、Windowsイベント監視情報のリストを受け取り、
+				 * リロードフラグをオフにする。
+				 */
+				m_log.debug("run : disconnectCounter=" + disconnectCounter);
+				if (disconnectCounter != 0 || isReloadFlg()) {
+					reloadLogfileMonitor(updateInfo, true);
+					reloadCustomMonitor(updateInfo, true);
+					reloadWinEventMonitor(updateInfo, true);
+					reloadJobFileCheck(updateInfo, true);
 					UpdateModuleUtil.setAgentLibMd5();
 					setReloadFlg(false);
 				}
+				disconnectCounter = 0;
+				setHistoryClear(false);
 
+				m_log.debug("run : topicInfoList.size=" + topicInfoList.size());
 				for (TopicInfo topicInfo : topicInfoList) {
-					m_log.info("getTopic facilityId=" + topicInfo.getFacilityId());
+					m_log.info("getTopic facilityId=" + topicInfo.getFacilityId() + ", flag=" + topicInfo.getFlag());
+
 					RunInstructionInfo runInstructionInfo = topicInfo.getRunInstructionInfo();
 					if (runInstructionInfo != null) {
 						runInstructionList.add(runInstructionInfo);
-						/*
-						 * コマンドタイプがCHECKの場合のみfastFlagをtrueにする。
-						 * その直後にメッセージが来るので。
-						 */
-						if (runInstructionInfo.getCommandType() == CommandTypeConstant.CHECK) {
-							m_log.debug("run : command=check");
-							fastCount = m_topicFastCount;
-						} else {
-							fastCount = 0;
-						}
 					}
+					
 					long topicFlag = topicInfo.getFlag();
-					if ((topicFlag & TopicFlagConstant.REPOSITORY_CHANGED) != 0 ||
-							(topicFlag & TopicFlagConstant.NEW_FACILITY) != 0 ||
-							(topicFlag & TopicFlagConstant.CALENDAR_CHANGED) != 0 ||
-							(topicFlag & TopicFlagConstant.LOGFILE_CHANGED) != 0) {
-						reloadLogfileMonitor();
-					}
-					if ((topicFlag & TopicFlagConstant.REPOSITORY_CHANGED) != 0 ||
-							(topicFlag & TopicFlagConstant.NEW_FACILITY) != 0 ||
-							(topicFlag & TopicFlagConstant.CALENDAR_CHANGED) != 0 ||
-							(topicFlag & TopicFlagConstant.CUSTOM_CHANGED) != 0) {
-						// コマンド監視のリロードを行う
-						reloadCommandMonitoring(updateInfo);
-					}
 					if (topicInfo.getAgentCommand() != 0) {
 						int agentCommand = topicInfo.getAgentCommand();
 						m_log.debug("agentCommand : " + agentCommand);
@@ -305,17 +250,52 @@ public class ReceiveTopic extends Thread {
 					if ((topicFlag & TopicFlagConstant.NEW_FACILITY) != 0) {
 						UpdateModuleUtil.setAgentLibMd5();
 					}
+					if (newTopicMode) {
+						continue;
+					}
+					// 以下の処理は不要。
+					// topic.mode=4.0の場合のみ動作する。
+					if ((topicFlag & TopicFlagConstant.REPOSITORY_CHANGED) != 0 ||
+							(topicFlag & TopicFlagConstant.NEW_FACILITY) != 0 ||
+							(topicFlag & TopicFlagConstant.CALENDAR_CHANGED) != 0 ||
+							(topicFlag & TopicFlagConstant.LOGFILE_CHANGED) != 0) {
+						reloadLogfileMonitor(updateInfo, true);
+					}
+					if ((topicFlag & TopicFlagConstant.REPOSITORY_CHANGED) != 0 ||
+							(topicFlag & TopicFlagConstant.NEW_FACILITY) != 0 ||
+							(topicFlag & TopicFlagConstant.CALENDAR_CHANGED) != 0 ||
+							(topicFlag & TopicFlagConstant.CUSTOM_CHANGED) != 0) {
+						reloadCustomMonitor(updateInfo, true);
+					}
+					if ((topicFlag & TopicFlagConstant.REPOSITORY_CHANGED) != 0 ||
+							(topicFlag & TopicFlagConstant.NEW_FACILITY) != 0 ||
+							(topicFlag & TopicFlagConstant.CALENDAR_CHANGED) != 0 ||
+							(topicFlag & TopicFlagConstant.WINEVENT_CHANGED) != 0) {
+						reloadWinEventMonitor(updateInfo, true);
+					}
+					if ((topicFlag & TopicFlagConstant.REPOSITORY_CHANGED) != 0 ||
+							(topicFlag & TopicFlagConstant.NEW_FACILITY) != 0 ||
+							(topicFlag & TopicFlagConstant.CALENDAR_CHANGED) != 0 ||
+							(topicFlag & TopicFlagConstant.FILECHECK_CHANGED) != 0) {
+						reloadJobFileCheck(updateInfo, true);
+					}
 				}
+
+				reloadLogfileMonitor(updateInfo, false);
+				reloadCustomMonitor(updateInfo, false);
+				reloadWinEventMonitor(updateInfo, false);
+				reloadJobFileCheck(updateInfo, false);
+
 				m_log.debug("getTopic " + Agent.getAgentStr() + " end");
-				if (runInstructionList.size() == 0) {
-					m_log.debug("infoList" + ".size() 0");
-					continue;
+				if (runInstructionList.size() > 0) {
+					m_log.info("infoList.size() = " + runInstructionList.size());
+				} else {
+					m_log.debug("infoList.size() = 0");
 				}
-				m_log.info("infoList.size() = " + runInstructionList.size());
 				for (RunInstructionInfo info : runInstructionList){
 					runJob(info);
 				}
-			} catch (Exception e) {
+			} catch (Throwable e) {
 				m_log.error("run() : " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			}
 		}
@@ -323,25 +303,79 @@ public class ReceiveTopic extends Thread {
 
 	public LogfileMonitorManager m_logManager = null;
 
-	private boolean isCommandMonitoringUpdated(SettingUpdateInfo updateInfo) {
-
+	/**
+	 *  リロードする必要がある場合はtrueを返す
+	 * @param updateInfo
+	 * @return
+	 */
+	private boolean isCustomMonitorReload(SettingUpdateInfo updateInfo) {
 		if (updateInfo == null) {
 			return false;
-		} else if (commandMonitorLastUpdateInfo == null) {
+		} else if (settingLastUpdateInfo == null) {
 			return true;
 		} else {
-			if (commandMonitorLastUpdateInfo.getCustomMonitorUpdateTime() == updateInfo.getCustomMonitorUpdateTime()
-					&& commandMonitorLastUpdateInfo.getCalendarUpdateTime() == updateInfo.getCalendarUpdateTime()
-					&& commandMonitorLastUpdateInfo.getRepositoryUpdateTime() == updateInfo.getRepositoryUpdateTime()) {
+			if (settingLastUpdateInfo.getCustomMonitorUpdateTime() == updateInfo.getCustomMonitorUpdateTime()
+					&& settingLastUpdateInfo.getCalendarUpdateTime() == updateInfo.getCalendarUpdateTime()
+					&& settingLastUpdateInfo.getRepositoryUpdateTime() == updateInfo.getRepositoryUpdateTime()) {
 				return false;
 			} else {
 				return true;
 			}
 		}
-
 	}
 
-	private void reloadCommandMonitoring(SettingUpdateInfo updateInfo) {
+	private boolean isWinEventMonitorReload(SettingUpdateInfo updateInfo) {
+		if (updateInfo == null) {
+			return false;
+		} else if (settingLastUpdateInfo == null) {
+			return true;
+		} else {
+			if (settingLastUpdateInfo.getWinEventMonitorUpdateTime() == updateInfo.getWinEventMonitorUpdateTime()
+					&& settingLastUpdateInfo.getCalendarUpdateTime() == updateInfo.getCalendarUpdateTime()
+					&& settingLastUpdateInfo.getRepositoryUpdateTime() == updateInfo.getRepositoryUpdateTime()) {
+				return false;
+			} else {
+				return true;
+			}
+		}
+	}
+
+	private boolean isLogfileMonitorReload(SettingUpdateInfo updateInfo) {
+		if (updateInfo == null) {
+			return false;
+		} else if (settingLastUpdateInfo == null) {
+			return true;
+		} else {
+			if (settingLastUpdateInfo.getLogFileMonitorUpdateTime() == updateInfo.getLogFileMonitorUpdateTime()
+					&& settingLastUpdateInfo.getCalendarUpdateTime() == updateInfo.getCalendarUpdateTime()
+					&& settingLastUpdateInfo.getRepositoryUpdateTime() == updateInfo.getRepositoryUpdateTime()) {
+				return false;
+			} else {
+				return true;
+			}
+		}
+	}
+
+	private boolean isJobFileCheckReload(SettingUpdateInfo updateInfo) {
+		if (updateInfo == null) {
+			return false;
+		} else if (settingLastUpdateInfo == null) {
+			return true;
+		} else {
+			if (settingLastUpdateInfo.getJobFileCheckUpdateTime() == updateInfo.getJobFileCheckUpdateTime()
+					&& settingLastUpdateInfo.getCalendarUpdateTime() == updateInfo.getCalendarUpdateTime()
+					&& settingLastUpdateInfo.getRepositoryUpdateTime() == updateInfo.getRepositoryUpdateTime()) {
+				return false;
+			} else {
+				return true;
+			}
+		}
+	}
+
+	private void reloadCustomMonitor(SettingUpdateInfo updateInfo, boolean force) {
+		if (!isCustomMonitorReload(updateInfo) && !force) {
+			return;
+		}
 		// Local Variables
 		ArrayList<CommandExecuteDTO> dtos = null;
 
@@ -349,7 +383,7 @@ public class ReceiveTopic extends Thread {
 		m_log.info("reloading configuration of custom monitoring...");
 		try {
 			dtos = AgentEndPointWrapper.getCommandExecuteDTOs();
-			
+
 			// unregister unnecessary Command Collector
 			for (CollectorId collectId : CollectorManager.getAllCollectorIds()) {
 				if (collectId.type != CommandCollector._collectorType) {
@@ -365,7 +399,7 @@ public class ReceiveTopic extends Thread {
 					CollectorManager.unregisterCollectorTask(collectId);
 				}
 			}
-			
+
 			// reset Command Collector
 			for (CommandExecuteDTO dto : dtos) {
 				m_log.info("reloaded configuration : " + CommandMonitoringWSUtil.toStringCommandExecuteDTO(dto));
@@ -373,9 +407,9 @@ public class ReceiveTopic extends Thread {
 			}
 
 			// update last update time
-			commandMonitorLastUpdateInfo = updateInfo;
+			settingLastUpdateInfo = updateInfo;
 			if (updateInfo != null) {
-				m_log.info("command monitor updated. (custom = " + updateInfo.getCalendarUpdateTime()
+				m_log.info("command monitor updated. (custom = " + updateInfo.getCustomMonitorUpdateTime()
 						+ ", calendar = " + updateInfo.getCalendarUpdateTime()
 						+ ", repository = " + updateInfo.getRepositoryUpdateTime() + ")");
 			}
@@ -392,17 +426,30 @@ public class ReceiveTopic extends Thread {
 
 	}
 
-	private void reloadLogfileMonitor () {
+	private void reloadLogfileMonitor (SettingUpdateInfo updateInfo, boolean force) {
+		if (!isLogfileMonitorReload(updateInfo) && !force) {
+			return;
+		}
 		m_log.info("reloading configuration of logfile monitoring...");
 		try {
 			ArrayList<MonitorInfo> list = AgentEndPointWrapper.getMonitorLogfile();
 
 			for (MonitorInfo info : list) {
-				m_log.info("logfile: filepath=" + info.getLogfileCheckInfo().getLogfile() +
+				m_log.info("logfile: " +
+						"directory=" + info.getLogfileCheckInfo().getDirectory() +
+						", filename=" + info.getLogfileCheckInfo().getFileName() +
 						", monitorId=" + info.getMonitorId() +
 						", monitorFlg=" + info.getMonitorFlg());
 			}
-			m_logManager.setLogfileMonitor(list);
+			LogfileMonitorManager.setLogfileMonitor(list);
+
+			// update last update time
+			settingLastUpdateInfo = updateInfo;
+			if (updateInfo != null) {
+				m_log.info("logfile monitor updated. (logfile = " + updateInfo.getLogFileMonitorUpdateTime()
+						+ ", calendar = " + updateInfo.getCalendarUpdateTime()
+						+ ", repository = " + updateInfo.getRepositoryUpdateTime() + ")");
+			}
 		} catch (HinemosUnknown_Exception e) {
 			m_log.error(e,e);
 		} catch (InvalidRole_Exception e) {
@@ -414,104 +461,152 @@ public class ReceiveTopic extends Thread {
 		}
 	}
 
+	private void reloadWinEventMonitor (SettingUpdateInfo updateInfo, boolean force) {
+		if (!isWinEventMonitorReload(updateInfo) && !force) {
+			return;
+		}
+		// OSがWindows以外の場合、スキップする
+		String osName = System.getProperty("os.name");
+		if(osName == null || ! osName.startsWith("Windows")){
+			return;
+		}
+
+		m_log.info("reloading configuration of windows event monitoring...");
+		try {
+			ArrayList<MonitorInfo> list = AgentEndPointWrapper.getMonitorWinEvent();
+			m_log.debug("windows event monitoring list size : " + list.size());
+
+			// unregister unnecessary WinEvent Collector
+			for (CollectorId collectId : CollectorManager.getAllCollectorIds()) {
+				if (collectId.type != WinEventCollector._collectorType) {
+					continue;
+				}
+				CollectorManager.unregisterCollectorTask(collectId);
+			}
+
+			// reset WinEvent Collector
+			for (MonitorInfo info : list) {
+				m_log.info("winevent: critical=" + info.getWinEventCheckInfo().isLevelCritical() +
+						", warning=" + info.getWinEventCheckInfo().isLevelWarning() +
+						", verbose=" + info.getWinEventCheckInfo().isLevelVerbose() +
+						", error=" + info.getWinEventCheckInfo().isLevelError() +
+						", informational=" + info.getWinEventCheckInfo().isLevelInformational() +
+						", monitorId=" + info.getMonitorId() +
+						", monitorFlg=" + info.getMonitorFlg());
+				if (info.getMonitorFlg() == ValidConstant.TYPE_INVALID) {
+					m_log.debug("WinEventMonitorThread(monitorId=" + info.getMonitorId()+ ") start is skipped because of monitor flg");
+					continue;
+				}
+
+				CollectorManager.registerCollectorTask(new WinEventCollector(info, m_sendQueue));
+			}
+
+			// update last update time
+			settingLastUpdateInfo = updateInfo;
+			if (updateInfo != null) {
+				m_log.info("winevent monitor updated. (winevent = " + updateInfo.getWinEventMonitorUpdateTime()
+						+ ", calendar = " + updateInfo.getCalendarUpdateTime()
+						+ ", repository = " + updateInfo.getRepositoryUpdateTime() + ")");
+			}
+
+		} catch (HinemosUnknown_Exception e) {
+			m_log.error(e,e);
+		} catch (InvalidRole_Exception e) {
+			m_log.warn("realoadWinEventMonitor: " + e.getMessage());
+		} catch (InvalidUserPass_Exception e) {
+			m_log.warn("realoadWinEventMonitor: " + e.getMessage());
+		} catch (MonitorNotFound_Exception e) {
+			m_log.warn("realoadWinEventMonitor: " + e.getMessage());
+		}
+
+	}
+
+	private void reloadJobFileCheck (SettingUpdateInfo updateInfo, boolean force) {
+		if (!isJobFileCheckReload(updateInfo) && !force) {
+			return;
+		}
+		m_log.info("reloading configuration of filecheck monitoring...");
+		try {
+			ArrayList<JobFileCheck> list = AgentEndPointWrapper.getFileCheckForAgent();
+
+			for (JobFileCheck info : list) {
+				m_log.info("filecheck: directory=" + info.getDirectory() +
+						", id=" + info.getId() +
+						", valid=" + info.getValid());
+			}
+			FileCheckManager.setFileCheck(list);
+		} catch (HinemosUnknown_Exception e) {
+			m_log.error(e,e);
+		} catch (InvalidRole_Exception e) {
+			m_log.warn("realoadLogfileMonitor: " + e.getMessage());
+		} catch (InvalidUserPass_Exception e) {
+			m_log.warn("realoadLogfileMonitor: " + e.getMessage());
+		} catch (JobMasterNotFound_Exception e) {
+			m_log.warn("realoadLogfileMonitor: " + e.getMessage());
+		} catch (MonitorNotFound_Exception e) {
+			m_log.warn("realoadLogfileMonitor: " + e.getMessage());
+		}
+	}
+
 	private void runJob (RunInstructionInfo info) {
 		m_log.debug("onMessage SessionID=" + info.getSessionId()
 				+ ", JobID=" + info.getJobId()
 				+ ", CommandType=" + info.getCommandType());
 
-		if(info.getCommandType() == CommandTypeConstant.CHECK){
-			//受信メッセージ応答
-			m_log.debug("onMessage CommandType = CHECK");
+		m_log.debug("onMessage CommandType != CHECK");
 
-			RunResultInfo resultInfo = new RunResultInfo();
-			resultInfo.setSessionId(info.getSessionId());
-			resultInfo.setJobunitId(info.getJobunitId());
-			resultInfo.setJobId(info.getJobId());
-			resultInfo.setFacilityId(info.getFacilityId());
-			resultInfo.setCommandType(info.getCommandType());
-
-			m_sendQueue.put(resultInfo);
-		}
-		else if(info.getCommandType() == CommandTypeConstant.DELETE_NORMAL_HISTORY ||
-				info.getCommandType() == CommandTypeConstant.DELETE_STOP_HISTORY){
-			//受信メッセージ応答
-			m_log.debug("onMessage CommandType = DELETE_NORMAL_HISTORY or DELETE_STOP_HISTORY");
-
-			//実行履歴削除
-			RunHistoryUtil.delRunHistory(info, m_runHistory);
-		}
-		else {
-			m_log.debug("onMessage CommandType != CHECK");
-
-			//実行履歴チェック
-			Date startDate = RunHistoryUtil.findRunHistory(info, m_runHistory);
-			if(startDate != null){
-				//実行履歴がある場合、開始メッセージを送信する
-
-				RunResultInfo resultInfo = new RunResultInfo();
-				resultInfo.setSessionId(info.getSessionId());
-				resultInfo.setJobunitId(info.getJobunitId());
-				resultInfo.setJobId(info.getJobId());
-				resultInfo.setFacilityId(info.getFacilityId());
-				resultInfo.setCommand(info.getCommand());
-				resultInfo.setCommandType(info.getCommandType());
-				resultInfo.setStatus(RunStatusConstant.START);
-				resultInfo.setTime(startDate.getTime());
-
-				m_log.info("run SessionID=" + info.getSessionId() + ", JobID=" + info.getJobId());
-
-				//送信
-				m_sendQueue.put(resultInfo);
-			}
-			else{
+		//実行履歴チェック
+		try{
+			if (RunHistoryUtil.findRunHistory(info) == null) {
 				if(info.getCommand().equals(CommandConstant.GET_PUBLIC_KEY) ||
 						info.getCommand().equals(CommandConstant.ADD_PUBLIC_KEY) ||
 						info.getCommand().equals(CommandConstant.DELETE_PUBLIC_KEY)){
 					//公開鍵用スレッド実行
 					m_log.debug("onMessage CommandType = GET_PUBLIC_KEY or ADD_PUBLIC_KEY or DELETE_PUBLIC_KEY");
 
-					PublicKeyThread thread = new PublicKeyThread(info, m_sendQueue, m_runHistory);
+					PublicKeyThread thread = new PublicKeyThread(info, m_sendQueue);
 					thread.start();
-				}
-				else if(info.getCommand().equals(CommandConstant.GET_FILE_LIST)){
+				}else if(info.getCommand().equals(CommandConstant.GET_FILE_LIST)){
 					//ファイルリスト用スレッド実行
 					m_log.debug("onMessage CommandType = GET_FILE_LIST");
 
-					FileListThread thread = new FileListThread(info, m_sendQueue, m_runHistory);
+					FileListThread thread = new FileListThread(info, m_sendQueue);
 					thread.start();
-				}
-				else if(info.getCommand().equals(CommandConstant.GET_CHECKSUM) ||
+				}else if(info.getCommand().equals(CommandConstant.GET_CHECKSUM) ||
 						info.getCommand().equals(CommandConstant.CHECK_CHECKSUM)){
 					//チェックサム用スレッド実行
 					m_log.debug("onMessage CommandType = GET_CHECKSUM or CHECK_CHECKSUM");
 
-					CheckSumThread thread = new CheckSumThread(info, m_sendQueue, m_runHistory);
+					CheckSumThread thread = new CheckSumThread(info, m_sendQueue);
 					thread.start();
-				}
-				else{
+				}else if(info.getCommandType() == CommandTypeConstant.NORMAL ||
+						(info.getCommandType() == CommandTypeConstant.STOP && info.getStopType() == CommandStopTypeConstant.EXECUTE_COMMAND)){
 					//コマンド実行
-					CommandThread thread = new CommandThread(info, m_sendQueue, m_runHistory);
+					CommandThread thread = new CommandThread(info, m_sendQueue);
 					thread.start();
+				} else  if (info.getCommandType() == CommandTypeConstant.STOP
+						&& info.getStopType() == CommandStopTypeConstant.DESTROY_PROCESS) {
+					// ここには普通はこないが、ジョブ実行中に再起動した場合にくる
+					m_log.warn("runJob() : logical error, runHistory = null, DESTROY_PROCESS");
+					DeleteProcessThread thread = new DeleteProcessThread(info, m_sendQueue);
+					thread.start();
+				} else {
+					//ここは通らないはず
+					m_log.warn("runJob() : logical error, runHistory = null");
+				}
+			}else {
+				if (info.getCommandType() == CommandTypeConstant.STOP
+						&& info.getStopType() == CommandStopTypeConstant.DESTROY_PROCESS) {
+					// プロセス終了
+					DeleteProcessThread thread = new DeleteProcessThread(info, m_sendQueue);
+					thread.start();
+				} else {
+					// ここは通らないはず
+					m_log.warn("runJob() : logical error, runHistory != null");
 				}
 			}
-		}
-	}
-
-	/**
-	 * 実行履歴をログに出力
-	 * @return
-	 */
-	protected void logHistory() {
-
-		synchronized (m_runHistory) {
-
-			try {
-				for(String key : m_runHistory.keySet()) {
-					m_log.info("A running job is out of control due to stopped agent : " + key);
-				}
-			} catch (ConcurrentModificationException e) {
-				m_log.warn("Log output process is stopped due to job execution history updated at the same time.");
-			}
+		} catch(Throwable e) {
+			m_log.warn("hoge " + e.getMessage(), e);
 		}
 	}
 
@@ -520,7 +615,7 @@ public class ReceiveTopic extends Thread {
 	 * clearFlgの設定
 	 * @param clearFlg
 	 */
-	synchronized private static void setClearFlg(boolean clearFlg) {
+	private static void setHistoryClear(boolean clearFlg) {
 		m_clearFlg = clearFlg;
 	}
 
@@ -528,24 +623,27 @@ public class ReceiveTopic extends Thread {
 	 * clearFlgの取得
 	 * @return
 	 */
-	synchronized static public boolean isHistoryClear(){
+	public static boolean isHistoryClear(){
 		return m_clearFlg;
 	}
-
-	/**
-	 * reloadFlgの設定
-	 */
-	synchronized public static void setReloadFlg(boolean reloadFlg) {
-		m_reloadFlg = reloadFlg;
-	}
 	
 	/**
-	 * reloadFlgの取得
+	 * reloadFlgの設定
+	 * @param reloadFlog
 	 */
-	synchronized public static boolean isReloadMonitor() {
+	public static void setReloadFlg(boolean reloadFlg) {
+		m_reloadFlg = reloadFlg;
+	}
+
+	/**
+	 * reloadFlgの取得
+	 * @return
+	 */
+	public static boolean isReloadFlg(){
 		return m_reloadFlg;
 	}
 	
+	
 	/**
 	 * ジョブ実行履歴削除
 	 * 通信エラーとなった場合に、一定時間後、ジョブ履歴情報を削除する
@@ -553,9 +651,9 @@ public class ReceiveTopic extends Thread {
 	public void clearJobHistory() {
 		m_log.debug("clearJobHistory start");
 		try{
-			if (RunHistoryUtil.clearRunHistory(m_runHistory)) {
+			if (RunHistoryUtil.clearRunHistory()) {
 				m_log.info("job history was deleted.");
-				setClearFlg(true);
+				setHistoryClear(true);
 			}
 		} catch (Exception e) {
 			m_log.error("clearJobHistory : ", e);
