@@ -29,70 +29,6 @@ public class ObjectFactory {
     public ObjectFactory() {
     }
 
-    /**
-     * Create an instance of {@link MonitorInfo }
-     * 
-     */
-    public MonitorInfo createMonitorInfo() {
-        return new MonitorInfo();
-    }
-
-    /**
-     * Create an instance of {@link PingCheckInfo }
-     * 
-     */
-    public PingCheckInfo createPingCheckInfo() {
-        return new PingCheckInfo();
-    }
-
-    /**
-     * Create an instance of {@link HttpCheckInfo }
-     * 
-     */
-    public HttpCheckInfo createHttpCheckInfo() {
-        return new HttpCheckInfo();
-    }
-
-    /**
-     * Create an instance of {@link CustomCheckInfo }
-     * 
-     */
-    public CustomCheckInfo createCustomCheckInfo() {
-        return new CustomCheckInfo();
-    }
-
-    /**
-     * Create an instance of {@link ProcessCheckInfo }
-     * 
-     */
-    public ProcessCheckInfo createProcessCheckInfo() {
-        return new ProcessCheckInfo();
-    }
-
-    /**
-     * Create an instance of {@link MonitorCheckInfo }
-     * 
-     */
-    public MonitorCheckInfo createMonitorCheckInfo() {
-        return new MonitorCheckInfo();
-    }
-
-    /**
-     * Create an instance of {@link TrapCheckInfo }
-     * 
-     */
-    public TrapCheckInfo createTrapCheckInfo() {
-        return new TrapCheckInfo();
-    }
-
-    /**
-     * Create an instance of {@link CommandVariableDTO.Variables.Entry }
-     * 
-     */
-    public CommandVariableDTO.Variables.Entry createCommandVariableDTOVariablesEntry() {
-        return new CommandVariableDTO.Variables.Entry();
-    }
-
     /**
      * Create an instance of {@link CommandResultDTO }
      * 
@@ -101,46 +37,6 @@ public class ObjectFactory {
         return new CommandResultDTO();
     }
 
-    /**
-     * Create an instance of {@link MonitorTrapValueInfo }
-     * 
-     */
-    public MonitorTrapValueInfo createMonitorTrapValueInfo() {
-        return new MonitorTrapValueInfo();
-    }
-
-    /**
-     * Create an instance of {@link CommandResultDTO.InvalidLines.Entry }
-     * 
-     */
-    public CommandResultDTO.InvalidLines.Entry createCommandResultDTOInvalidLinesEntry() {
-        return new CommandResultDTO.InvalidLines.Entry();
-    }
-
-    /**
-     * Create an instance of {@link CommandVariableDTO.Variables }
-     * 
-     */
-    public CommandVariableDTO.Variables createCommandVariableDTOVariables() {
-        return new CommandVariableDTO.Variables();
-    }
-
-    /**
-     * Create an instance of {@link CommandExecuteDTO }
-     * 
-     */
-    public CommandExecuteDTO createCommandExecuteDTO() {
-        return new CommandExecuteDTO();
-    }
-
-    /**
-     * Create an instance of {@link PerfCheckInfo }
-     * 
-     */
-    public PerfCheckInfo createPerfCheckInfo() {
-        return new PerfCheckInfo();
-    }
-
     /**
      * Create an instance of {@link CommandResultDTO.Results }
      * 
@@ -149,6 +45,54 @@ public class ObjectFactory {
         return new CommandResultDTO.Results();
     }
 
+    /**
+     * Create an instance of {@link CommandResultDTO.InvalidLines }
+     * 
+     */
+    public CommandResultDTO.InvalidLines createCommandResultDTOInvalidLines() {
+        return new CommandResultDTO.InvalidLines();
+    }
+
+    /**
+     * Create an instance of {@link CommandVariableDTO }
+     * 
+     */
+    public CommandVariableDTO createCommandVariableDTO() {
+        return new CommandVariableDTO();
+    }
+
+    /**
+     * Create an instance of {@link CommandVariableDTO.Variables }
+     * 
+     */
+    public CommandVariableDTO.Variables createCommandVariableDTOVariables() {
+        return new CommandVariableDTO.Variables();
+    }
+
+    /**
+     * Create an instance of {@link CustomCheckInfo }
+     * 
+     */
+    public CustomCheckInfo createCustomCheckInfo() {
+        return new CustomCheckInfo();
+    }
+
+    /**
+     * Create an instance of {@link MonitorTrapValueInfo }
+     * 
+     */
+    public MonitorTrapValueInfo createMonitorTrapValueInfo() {
+        return new MonitorTrapValueInfo();
+    }
+
+    /**
+     * Create an instance of {@link TrapCheckInfo }
+     * 
+     */
+    public TrapCheckInfo createTrapCheckInfo() {
+        return new TrapCheckInfo();
+    }
+
     /**
      * Create an instance of {@link MonitorTruthValueInfo }
      * 
@@ -158,19 +102,11 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link MonitorNumericValueInfo }
+     * Create an instance of {@link MonitorInfo }
      * 
      */
-    public MonitorNumericValueInfo createMonitorNumericValueInfo() {
-        return new MonitorNumericValueInfo();
-    }
-
-    /**
-     * Create an instance of {@link CommandResultDTO.Results.Entry }
-     * 
-     */
-    public CommandResultDTO.Results.Entry createCommandResultDTOResultsEntry() {
-        return new CommandResultDTO.Results.Entry();
+    public MonitorInfo createMonitorInfo() {
+        return new MonitorInfo();
     }
 
     /**
@@ -182,35 +118,27 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link SnmpCheckInfo }
+     * Create an instance of {@link PingCheckInfo }
      * 
      */
-    public SnmpCheckInfo createSnmpCheckInfo() {
-        return new SnmpCheckInfo();
+    public PingCheckInfo createPingCheckInfo() {
+        return new PingCheckInfo();
     }
 
     /**
-     * Create an instance of {@link CommandResultDTO.InvalidLines }
+     * Create an instance of {@link ProcessCheckInfo }
      * 
      */
-    public CommandResultDTO.InvalidLines createCommandResultDTOInvalidLines() {
-        return new CommandResultDTO.InvalidLines();
+    public ProcessCheckInfo createProcessCheckInfo() {
+        return new ProcessCheckInfo();
     }
 
     /**
-     * Create an instance of {@link PortCheckInfo }
+     * Create an instance of {@link PerfCheckInfo }
      * 
      */
-    public PortCheckInfo createPortCheckInfo() {
-        return new PortCheckInfo();
-    }
-
-    /**
-     * Create an instance of {@link MonitorJudgementInfo }
-     * 
-     */
-    public MonitorJudgementInfo createMonitorJudgementInfo() {
-        return new MonitorJudgementInfo();
+    public PerfCheckInfo createPerfCheckInfo() {
+        return new PerfCheckInfo();
     }
 
     /**
@@ -222,11 +150,19 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link CommandVariableDTO }
+     * Create an instance of {@link HttpCheckInfo }
      * 
      */
-    public CommandVariableDTO createCommandVariableDTO() {
-        return new CommandVariableDTO();
+    public HttpCheckInfo createHttpCheckInfo() {
+        return new HttpCheckInfo();
+    }
+
+    /**
+     * Create an instance of {@link PluginCheckInfo }
+     * 
+     */
+    public PluginCheckInfo createPluginCheckInfo() {
+        return new PluginCheckInfo();
     }
 
     /**
@@ -245,4 +181,100 @@ public class ObjectFactory {
         return new LogfileCheckInfo();
     }
 
+    /**
+     * Create an instance of {@link MonitorPluginNumericInfo }
+     * 
+     */
+    public MonitorPluginNumericInfo createMonitorPluginNumericInfo() {
+        return new MonitorPluginNumericInfo();
+    }
+
+    /**
+     * Create an instance of {@link MonitorNumericValueInfo }
+     * 
+     */
+    public MonitorNumericValueInfo createMonitorNumericValueInfo() {
+        return new MonitorNumericValueInfo();
+    }
+
+    /**
+     * Create an instance of {@link SnmpCheckInfo }
+     * 
+     */
+    public SnmpCheckInfo createSnmpCheckInfo() {
+        return new SnmpCheckInfo();
+    }
+
+    /**
+     * Create an instance of {@link MonitorCheckInfo }
+     * 
+     */
+    public MonitorCheckInfo createMonitorCheckInfo() {
+        return new MonitorCheckInfo();
+    }
+
+    /**
+     * Create an instance of {@link MonitorPluginStringInfo }
+     * 
+     */
+    public MonitorPluginStringInfo createMonitorPluginStringInfo() {
+        return new MonitorPluginStringInfo();
+    }
+
+    /**
+     * Create an instance of {@link CommandExecuteDTO }
+     * 
+     */
+    public CommandExecuteDTO createCommandExecuteDTO() {
+        return new CommandExecuteDTO();
+    }
+
+    /**
+     * Create an instance of {@link MonitorJudgementInfo }
+     * 
+     */
+    public MonitorJudgementInfo createMonitorJudgementInfo() {
+        return new MonitorJudgementInfo();
+    }
+
+    /**
+     * Create an instance of {@link WinEventCheckInfo }
+     * 
+     */
+    public WinEventCheckInfo createWinEventCheckInfo() {
+        return new WinEventCheckInfo();
+    }
+
+    /**
+     * Create an instance of {@link PortCheckInfo }
+     * 
+     */
+    public PortCheckInfo createPortCheckInfo() {
+        return new PortCheckInfo();
+    }
+
+    /**
+     * Create an instance of {@link CommandResultDTO.Results.Entry }
+     * 
+     */
+    public CommandResultDTO.Results.Entry createCommandResultDTOResultsEntry() {
+        return new CommandResultDTO.Results.Entry();
+    }
+
+    /**
+     * Create an instance of {@link CommandResultDTO.InvalidLines.Entry }
+     * 
+     */
+    public CommandResultDTO.InvalidLines.Entry createCommandResultDTOInvalidLinesEntry() {
+        return new CommandResultDTO.InvalidLines.Entry();
+    }
+
+    /**
+     * Create an instance of {@link CommandVariableDTO.Variables.Entry }
+     * 
+     */
+    public CommandVariableDTO.Variables.Entry createCommandVariableDTOVariablesEntry() {
+        return new CommandVariableDTO.Variables.Entry();
+    }
+
 }
